@@ -17,14 +17,6 @@
 
 context("test MDR function")
 
-if (dir.exists("../../00_pkg_src")) {
-  prefix <- "../../00_pkg_src/DQAstats/"
-} else if (dir.exists("../../R")) {
-  prefix <- "../../"
-} else if (dir.exists("./R")) {
-  prefix <- "./"
-}
-
 library(data.table)
 
 test_that("correct functioning of MDR", {
