@@ -17,15 +17,6 @@
 
 context("test dataloading")
 
-if (dir.exists("../../00_pkg_src")) {
-  prefix <- "../../00_pkg_src/DQAstats/"
-} else if (dir.exists("../../R")) {
-  prefix <- "../../"
-} else if (dir.exists("./R")) {
-  prefix <- "./"
-}
-
-
 library(data.table)
 
 test_that("correct functioning of dataloading", {
@@ -163,7 +154,6 @@ test_that("correct functioning of dataloading", {
   do.call(file.remove, list(list.files(
     paste0(output_dir, "_header"), full.names = TRUE
   )))
-  unlink(paste0(output_dir, "_header"), recursive = T)
-  unlink(output_dir, recursive = T)
-  file.remove(paste0(prefix, "tests/testthat/logfile.log"))
+  unlink(paste0(output_dir, "_header"), recursive = TRUE)
+  unlink(output_dir, recursive = TRUE)
 })
